{% extends "layout.html" %}

{% block title %}{% trans %}Server Specifications{% endtrans %}{% endblock %}

{% block content %}
    <h2>{% trans %}Server Specifications{% endtrans %}</h2>

    {% if supported_specs %}
        <article>
            <header><h3>{% trans count=supported_specs|length %}Supported specifications ({{ count }}){% endtrans %}</h3></header>
            <ul>
                {% for spec_id, spec_name, spec_url in supported_specs %}
                    <li><code>{{ spec_id }}</code>: <a href="{{ spec_url }}" target="_blank" rel="noopener noreferrer">{{ spec_name }}</a></li>
                {% endfor %}
            </ul>
        </article>
    {% endif %}

    {% if unsupported_specs %}
        <article>
            <header><h3>{% trans count=unsupported_specs|length %}Unsupported specifications ({{ count }}){% endtrans %}</h3></header>
            <ul>
                {% for spec_id, spec_name, spec_url in unsupported_specs %}
                    <li><code>{{ spec_id }}</code>: <a href="{{ spec_url }}" target="_blank" rel="noopener noreferrer">{{ spec_name }}</a></li>
                {% endfor %}
            </ul>
        </article>
    {% endif %}

    {% if unknown_specs %}
        <article>
            <header><h3>{% trans count=unknown_specs|length %}Unknown specifications ({{ count }}){% endtrans %}</h3></header>
            <ul>
                {% for spec_id, spec_name, spec_url in unknown_specs %}
                    <li><code>{{ spec_id }}</code>: <a href="{{ spec_url }}" target="_blank" rel="noopener noreferrer">{{ spec_name }}</a></li>
                {% endfor %}
            </ul>
        </article>
    {% endif %}
{% endblock %}
